summaryrefslogtreecommitdiffstats
path: root/tdecore/kprocctrl.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/kprocctrl.h')
-rw-r--r--tdecore/kprocctrl.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/tdecore/kprocctrl.h b/tdecore/kprocctrl.h
index fbd096cbf..1cb6cc302 100644
--- a/tdecore/kprocctrl.h
+++ b/tdecore/kprocctrl.h
@@ -27,16 +27,16 @@
class TQSocketNotifier;
/**
* @short Used internally by KProcess
* @internal
* @author Christian Czezatke <e9025461@student.tuwien.ac.at>
*
* A class for internal use by KProcess only. -- Exactly one instance
* of this class is created by TDEApplication.
*
* This class takes care of the actual (UN*X) signal handling.
*/
-class TDECORE_EXPORT KProcessController : public TQObject
+class TDECORE_EXPORT TDEProcessController : public TQObject
{
Q_OBJECT
@@ -57,7 +57,7 @@ public:
* Only a single instance of this class is allowed at a time,
* and this static variable is used to track the one instance.
*/
- static KProcessController *theKProcessController; // kde4: rename: instance
+ static TDEProcessController *theTDEProcessController; // kde4: rename: instance
/**
* Automatically called upon SIGCHLD. Never call it directly.
@@ -71,7 +71,7 @@ public:
/**
* Wait for any process to exit and handle their exit without
* starting an event loop.
* This function may cause KProcess to emit any of its signals.
*
* @param timeout the timeout in seconds. -1 means no timeout.
* @return true if a process exited, false
@@ -95,7 +95,7 @@ public:
void rescheduleCheck();
/*
* Obtain the file descriptor KProcessController uses to get notified
* about process exits. select() or poll() on it if you create a custom
* event loop that needs to act upon SIGCHLD.
* @return the file descriptor of the reading end of the notification pipe
@@ -106,11 +106,11 @@ public:
/**
* @internal
*/
- void addKProcess( KProcess* );
+ void addTDEProcess( TDEProcess* );
/**
* @internal
*/
- void removeKProcess( KProcess* );
+ void removeTDEProcess( TDEProcess* );
/**
* @internal
*/
@@ -125,7 +125,7 @@ private:
int fd[2];
bool needcheck;
TQSocketNotifier *notifier;
- TQValueList<KProcess*> kProcessList;
+ TQValueList<TDEProcess*> kProcessList;
TQValueList<int> unixProcessList;
static void setupHandlers();
@@ -136,12 +136,12 @@ private:
static int refCount;
// Disallow instantiation
- KProcessController();
- ~KProcessController();
+ TDEProcessController();
+ ~TDEProcessController();
// Disallow assignment and copy-construction
- KProcessController( const KProcessController& );
- KProcessController& operator= ( const KProcessController& );
+ TDEProcessController( const TDEProcessController& );
+ TDEProcessController& operator= ( const TDEProcessController& );
};
@@ -27,16 +27,16 @@
class TQSocketNotifier;
/**
- * @short Used internally by KProcess
+ * @short Used internally by TDEProcess
* @internal
* @author Christian Czezatke <e9025461@student.tuwien.ac.at>
@@ -27,16 +27,16 @@
* @author Christian Czezatke <e9025461@student.tuwien.ac.at>
*
- * A class for internal use by KProcess only. -- Exactly one instance
+ * A class for internal use by TDEProcess only. -- Exactly one instance
* of this class is created by TDEApplication.
*
@@ -71,7 +71,7 @@ public:
* Wait for any process to exit and handle their exit without
* starting an event loop.
- * This function may cause KProcess to emit any of its signals.
+ * This function may cause TDEProcess to emit any of its signals.
*
* @param timeout the timeout in seconds. -1 means no timeout.
@@ -95,7 +95,7 @@ public:
void rescheduleCheck();
/*
- * Obtain the file descriptor KProcessController uses to get notified
+ * Obtain the file descriptor TDEProcessController uses to get notified
* about process exits. select() or poll() on it if you create a custom
* event loop that needs to act upon SIGCHLD.